@@ -45,13 +45,4 @@ def process_urls(urls, my_new_val):
             process_url(new_url_base, param_vals, my_new_val)
 
 
-def main():
-    usage(argv)
-    urls = read_urls(argv[1])
-    my_new_val = argv[2]
-    process_urls(urls, my_new_val)
-    
-
-if __name__ == '__main__':
-    main()
 
